
.SH NAME
\fIr.sun\fR \- computes solar rays incidence angle raster maps for given time
and latitude, and amount of direct solar energy raster maps for given day
and latitude from elevation, slope and aspect raster files. The shading effect 
of surrounding terrain is incorporated.

.br
\fI(GRASS Raster Program)\fR
.SH SYNOPSIS
.B r.sun
.br
\fBr.sun help\fR
.br
\fBr.sun \fR [\fB-s\fR]
 \fBelevin = name\fR [\fBzmult\fR] \fBaspin = name\fR \fBslopein = name\fR
 [\fBincidout = name\fR] [\fBenergyout = name\fR] \fBlatitude\fR
 \fBdej\fR [\fBlum_time\fR]

.SH DESCRIPTION
\fIr.sun\fR

.br
This program computes solar rays incidence angle raster map \fIincidout\fR for
given day \fIdej\fR, time \fIlum_time\fR and latitude \fIlatitude\fR and amount
of direct solar energy \fIenergyout\fR  for a given day \fIdej\fR
and latitude from elevation \fIelevin\fR, slope \fIslopein\fR
and aspect \fIaspin\fR raster files. If elevations in the raster elevation
map \fIelevin\fR are in different units than the mapset coordinate system, 
a multiplier \fIzmult\fR must be used. For instance, if elevations
are in centimeters and x, y coordinates in meters, you should use
\fIzmult\fR = 100. Specified day \fIdej\fR is the
number where January 1 is day no.1 and December 31 is 365 (366).
Time \fIlum_time\fR must be a local time in decimal system, e.g.
7.5 (i.e. 7h 30m). Latitude must be also in decimal system and has 
positive values for northern hemisphere and negative for southern one.
Incidence angle is angle between normal vector of given surface and solar ray
vector. Output incidence angles are in degrees.
Amount of direct solar energy for given day is computed integrating the 
incidence angle between sunrise and sunset times. Ouput is in kW per 
squared meter.
The incidence angle and amount of direct solar energy can be computed
without shading influence of surrounding terrain by default, they can be 
computed incorporating this influnce using the flag \fI-s\fR. In hilly
areas this can lead to very different results!
A declination is computed internally using Cooper's approximation for each
day and energy input using solar constant 1370 kW per squared meter.
It is possible to compute an amount of direct solar energy for some
time interval during the year (e.g. a vegetation period). This can be done
using a shell script.
Elevation, aspect and slope input values should not be reclassified into
coarser categories. This could lead to incorrect results.



.SH OPTIONS
The user can run this program either interactively or non-interactively.
The program will be run non-interactively if the user specifies
program arguments and flag settings on the command line using the form:
.LP
.RS
\fBr.sun\fR [\fB-s\fR] \fBelevin = name\fR [\fBzmult = val\fR] \fBaspin = name\fR 
\fBslopein = name\fR [\fBincidout = name\fR] [\fBenergyout = name\fR]
\fBlatitude = val\fR \fBdej = val\fR [\fBlum_time = val\fR]

.RE
.LP
Alternately, the user can simply type \fBr.sun\fR on the command line
without program arguments.  In this case, the user will be prompted for
parameter values using the standard GRASS parser interface.

.LP
\fBFlag:\fR
.IP [\fB-s\fR] 18
Incorporates shading effect of terrain (default not)

.LP
\fBParameters:\fR
.IP \fBelevin\*=\fIname\fR 18
Use the existing raster file with elevations\fIname\fR as input.
.IP \fBzmult\*=\fIval\fR 18
Set a multiplier for elevations to \fIval\fR.
.IP \fBaspin\*=\fIname\fR 18
Use the existing raster file with aspect\fIname\fR as input.
.IP \fBslopein\*=\fIname\fR 18
Use the existing raster file with slope\fIname\fR as input.
.IP \fBincidout\*=\fIname\fR 18
Output solar rays incidence angle values to raster file named  \fIname\fR.
.IP \fBenergyout\*=\fIname\fR 18
Output direct solar energy values to raster file named  \fIname\fR.
.IP \fBlatitude\*=\fIval\fR 18
Set the value of latitude of given region to \fIval\fR.
.IP \fBdej\*=\fIval\fR 18
Set the serial number of day to \fIval\fR.
.IP \fBlum_time\*=\fIval\fR 18
Set the decimal value of time to \fIval\fR.

.SH NOTES

.br
Solar energy is important input parameter in different models concerning
landscape, vegetation, evapotranspiration, snowmelt or remote sensing.
Solar rays incidence angle can be effectively used in radiometric corrections
in hilly terrain where very precise investigations are performed.
Incidence angle multiplied by solar constant (here is used 1370 kW
per squared meter) gives irradiance which can be computed using r.mapcalc.

...


.TE
.LP
.SH "SEE ALSO"
.I "s.surf.tps, r.slope.aspect"
.SH "AUTHOR"
\fIOriginal version of the program \fR:
.br
Jaroslav Hofierka and Maros Zlocha,
Comenius University, Bratislava, Slovakia,
.br
.LP
\fIModified program (adapted for GRASS)\fR:
.br
Jaroslav Hofierka, Comenius University, Slovakia
.br
.br
.SH "REFERENCES"
.br
Mitasova, H. and Hofierka, J. (1993): Interpolation by Regularized Spline with
Tension: II. Aplication to Terrain Modeling and Surface Geometry Analysis.
Mathemtical Geology (in press).
.br
Krcho, J. (1977, 1990) ...
.br
Jenco, M. (1992): Distribution of direct solar radiation on georelief
and its modelling by means of complex digital model of terrain. Geograficky
casopis 44, 1992, pp.342-355.(in Slovak)

